import React from 'react';

declare const SYMBOL_KEY = "__wrap_b";
declare const SYMBOL_OBSERVER_KEY = "__wrap_o";
interface WrapperElement extends HTMLElement {
    [SYMBOL_OBSERVER_KEY]?: ResizeObserver | undefined;
}
declare type RelayoutFn = (id: string | number, ratio: number, wrapper?: WrapperElement) => void;
declare global {
    interface Window {
        [SYMBOL_KEY]: RelayoutFn;
    }
}
interface BalancerProps extends React.HTMLAttributes<HTMLElement> {
    /**
     * The HTML tag to use for the wrapper element.
     * @default 'span'
     */
    as?: React.ElementType;
    /**
     * The balance ratio of the wrapper width (0 <= ratio <= 1).
     * 0 means the wrapper width is the same as the container width (no balance, browser default).
     * 1 means the wrapper width is the minimum (full balance, most compact).
     * @default 1
     */
    ratio?: number;
    children?: React.ReactNode;
}
declare const Provider: React.FC<{
    children?: React.ReactNode;
}>;
declare const Balancer: React.FC<BalancerProps>;

export { Provider, Balancer as default };
